grim/guifications2

Lot's of s/gaim/pidgin/ cleanups..
org.guifications.gf2
2007-05-05, Gary Kramlich
75aa247f467b
Parents 0ec7f3cb75fe
Children a4ac9ef1893d
Lot's of s/gaim/pidgin/ cleanups..
--- a/src/gf_action.c Sat May 05 03:31:16 2007 -0400
+++ b/src/gf_action.c Sat May 05 03:39:01 2007 -0400
@@ -706,7 +706,7 @@
info = gf_display_get_event_info(display);
g_return_if_fail(info);
- /* get the gaim stuff we need */
+ /* get the pidgin stuff we need */
account = gf_event_info_get_account(info);
g_return_if_fail(account);
--- a/src/gf_blist.c Sat May 05 03:31:16 2007 -0400
+++ b/src/gf_blist.c Sat May 05 03:39:01 2007 -0400
@@ -223,7 +223,7 @@
gf_blist_menu_cb(PurpleBlistNode *node, gpointer data) {
/* Fix this up when we actually have a way to know if a request window
* is still visible, ie: remind me to write a patch for that and to
- * "show" that window for the next gaim release..
+ * "show" that window for a future pidgin release...
*/
gf_blist_dialog_new(node);
}
--- a/src/gf_preferences.c Sat May 05 03:31:16 2007 -0400
+++ b/src/gf_preferences.c Sat May 05 03:39:01 2007 -0400
@@ -1360,7 +1360,7 @@
purple_prefs_add_string(GF_PREF_MOUSE_MIDDLE, "close");
purple_prefs_add_string(GF_PREF_MOUSE_RIGHT, "context");
- def_theme = g_build_filename(DATADIR, "pixmaps", "gaim", "guifications",
+ def_theme = g_build_filename(DATADIR, "pixmaps", "pidgin", "guifications",
"themes", "default", "theme.xml", NULL);
l = g_list_append(l, def_theme);
purple_prefs_add_string_list(GF_PREF_LOADED_THEMES, l);
--- a/src/guifications.c Sat May 05 03:31:16 2007 -0400
+++ b/src/guifications.c Sat May 05 03:39:01 2007 -0400
@@ -96,40 +96,40 @@
};
static PurplePluginInfo gf_info = {
- PURPLE_PLUGIN_MAGIC, /* plugin magic */
- PURPLE_MAJOR_VERSION, /* major gaim version */
- PURPLE_MINOR_VERSION, /* minor gaim version */
- PURPLE_PLUGIN_STANDARD, /* type */
- PIDGIN_PLUGIN_TYPE, /* ui requirement */
- 0, /* flags */
- NULL, /* dependencies */
- PURPLE_PRIORITY_DEFAULT, /* priority */
+ PURPLE_PLUGIN_MAGIC,
+ PURPLE_MAJOR_VERSION,
+ PURPLE_MINOR_VERSION,
+ PURPLE_PLUGIN_STANDARD,
+ PIDGIN_PLUGIN_TYPE,
+ 0,
+ NULL,
+ PURPLE_PRIORITY_DEFAULT,
- "gtk-amc_grim-Guifications", /* id */
- NULL, /* name */
+ "gtk-amc_grim-Guifications",
+ NULL,
#ifdef _WIN32
GF_VERSION,
#else
- VERSION, /* version */
+ VERSION,
#endif
- NULL, /* summary */
- NULL, /* description */
+ NULL,
+ NULL,
- "Gary Kramlich <grim@guifications.org>", /* author */
- GF_WEBSITE, /* homepage */
+ "Gary Kramlich <grim@guifications.org>",
+ GF_WEBSITE,
- gf_load, /* load */
- gf_unload, /* unload */
- NULL, /* destroy */
+ gf_load,
+ gf_unload,
+ NULL,
- &ui_info, /* ui info */
- NULL, /* extra info */
- NULL, /* plugin prefs */
- NULL, /* plugin actions */
- NULL, /* reserved 1 */
- NULL, /* reserved 2 */
- NULL, /* reserved 3 */
- NULL /* reserved 4 */
+ &ui_info,
+ NULL,
+ NULL,
+ NULL,
+ NULL,
+ NULL,
+ NULL,
+ NULL
};
static void
--- a/src/gf_item_icon.c Sat May 05 03:31:16 2007 -0400
+++ b/src/gf_item_icon.c Sat May 05 03:39:01 2007 -0400
@@ -287,7 +287,7 @@
if(is_contact) {
gchar *filename;
- filename = g_build_filename(DATADIR, "pixmaps", "gaim.png",
+ filename = g_build_filename(DATADIR, "pixmaps", "pidgin.png",
NULL);
original = gdk_pixbuf_new_from_file(filename, NULL);
g_free(filename);
@@ -323,9 +323,10 @@
}
}
/* if the original doesn't work for whatever reason we fallback to the protocol or
* the gaim guy if it is a contact notification, this will be optional when we
* "enhance" the theme format. If it fails we return like we used to.
*/
if(!original) {
PurpleAccount *account = gf_event_info_get_account(info);
@@ -323,9 +323,10 @@
}
}
- /* if the original doesn't work for whatever reason we fallback to the protocol or
- * the gaim guy if it is a contact notification, this will be optional when we
- * "enhance" the theme format. If it fails we return like we used to.
+ /* if the original doesn't work for whatever reason we fallback to the
+ * protocol or the Pidgin guy(?) if it is a contact notification, this will
+ * be optional when we "enhance" the theme format. If it fails we return
+ * like we used to.
*/
if(!original) {